==> lumiHumanAll.db_1.2.0.tar.gz: lumiHumanAll.db/man/lumiHumanAll_dbconn.Rd <==
\name{lumiHumanAll_dbconn}

\alias{lumiHumanAll_dbconn}
\alias{lumiHumanAll_dbfile}
\alias{lumiHumanAll_dbschema}
\alias{lumiHumanAll_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  lumiHumanAll_dbconn()
  lumiHumanAll_dbfile()
  lumiHumanAll_dbschema(file="", show.indices=FALSE)
  lumiHumanAll_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{lumiHumanAll_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{lumiHumanAll_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{lumiHumanAll_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{lumiHumanAll_dbschema} prints the schema definition of the
  package annotation DB.

  \code{lumiHumanAll_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{lumiHumanAll_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{lumiHumanAll_dbfile}: a character string with the path to the
  package annotation DB.

  \code{lumiHumanAll_dbschema}: none (invisible \code{NULL}).

  \code{lumiHumanAll_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(lumiHumanAll_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by lumiHumanAll_dbconn() was created with:
  dbConnect(SQLite(), dbname=lumiHumanAll_dbfile(), cache_size=64000, synchronous=0)

  lumiHumanAll_dbschema()

  lumiHumanAll_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> lumiHumanAll.db_1.16.0.tar.gz: lumiHumanAll.db/man/lumiHumanAll_dbconn.Rd <==

\name{lumiHumanAll_dbconn}

\alias{lumiHumanAll_dbconn}
\alias{lumiHumanAll_dbfile}
\alias{lumiHumanAll_dbschema}
\alias{lumiHumanAll_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  lumiHumanAll_dbconn()
  lumiHumanAll_dbfile()
  lumiHumanAll_dbschema(file="", show.indices=FALSE)
  lumiHumanAll_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{lumiHumanAll_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{lumiHumanAll_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{lumiHumanAll_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{lumiHumanAll_dbschema} prints the schema definition of the
  package annotation DB.

  \code{lumiHumanAll_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{lumiHumanAll_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{lumiHumanAll_dbfile}: a character string with the path to the
  package annotation DB.

  \code{lumiHumanAll_dbschema}: none (invisible \code{NULL}).

  \code{lumiHumanAll_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(lumiHumanAll_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by lumiHumanAll_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=lumiHumanAll_dbfile(), cache_size=64000,
  synchronous=0)

  lumiHumanAll_dbschema()

  lumiHumanAll_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
